library(data.table)
library(tidyr)
library(dplyr)
library(gtools)
library(stringr)
library(magrittr)
titel <- "" #title
ondertitel1 <- '10% light power, 200msec per frame' #subtitle titel 1
TextatXaxis <- "FP"   #which label should the X axis have?
TextatYaxix <- "Photostability (remaining fluorescence at last timepoint)" #which label should the y axis have?
minutesperframe <- 200   #amount of msec per frame

# import data
wd <- choose.dir()     #set input folder
setwd(wd)              #set input folder
filelist = list.files(pattern = "results.*.txt")       #make a list with all the txtfiles in a folder
datalist = lapply(filelist, function(x)read.table(x, sep="\t", header=T)) 
combined = do.call("smartbind", datalist) 

# change format of frames with correct names
combined$X <- (combined$X*minutesperframe)-minutesperframe  #amount of msec per frame
combined2 <- gather(combined, Name, Fluorescence, starts_with("Mean")) #change format of the dataframe 
colnames(combined2)[3] <- "Cell"             #change column headers to the correct name
colnames(combined2)[4] <- "Fluorescence"    #change column headers to the correct name
colnames(combined2)[2] <- "Naam"          #change column headers to the correct name

#make extra id column to identify cells from more >1 experiment (otherwise both have mean1 for example)
library(dplyr)
detach("package:plyr", unload=TRUE) 
combined3 <- (
  combined2 %>% 
    group_by(X) %>% 
    mutate(id=1:n())
)

#remove cells that have really low fluorescence
combined3 <- (
  combined3 %>%
    group_by(id) %>%
    filter(!any(Fluorescence < 20))
)

#remove cells that have really high fluorescence
combined3 <- (
  combined3 %>%
    group_by(id) %>%
    filter(!any(Fluorescence > 60000))
)


#normalize to the first frame of the movie (bleaching curve) (baseline) # x:x selects rows
combined3normalized <-
  (
    combined3 %>% 
      group_by(Cell, Naam) %>%
      mutate(Fluorescence_norm=Fluorescence/mean(Fluorescence[1])) %>%         
      arrange(Naam, Cell)
  )

# #remove cells that fly away and get really low normalized fluorescence
library(dplyr)
combined3normalized <- (
  combined3normalized %>%
    group_by(Cell, Naam) %>%
    filter(!any(Fluorescence_norm < 0.1))
)


library(plotrix)
 
#add a variable to each cell in order to seperate cells from 2 different experiments (otherwise 2 cells will have the name mean1 for example)
combined3normalized <-
  (
    combined3normalized %>%
      group_by(Cell, Naam) %>%
      mutate(cellexp=paste(Naam, Cell)) %>%
      arrange(Naam, Cell, X)
  )



combined3normalized <- na.omit(combined3normalized)    #remove cells which do not have fluorescence value

#change names to correct FP
library(mosaic)
combined4 <- mutate(combined3normalized, Naam2 = derivedFactor(
  "mTq2" = str_detect(Naam, "tdtomato-t2a-mtq2_bleaching"),
  "ymVenus" = str_detect(Naam, "yemvenus-t2a-mtq2"),
  "ymNeongreen (as GFP)" = str_detect(Naam, "ymneongreen-t2a-mtq2"),
  "ymNeongreen (as YFP)" = str_detect(Naam, "ymneongreen-t2a-mcherry"),
  "ytdtomato" = str_detect(Naam, "ytdtomato-t2a-mtq2"),
  "yoeGFP" = str_detect(Naam, "yoeGFP-T2A-mCherry"),
  "mNeongreen (as YFP)" = str_detect(Naam, "mneongreen-T2A-mTq2"),
  "ymTq2" = str_detect(Naam, "ymtq2-t2a-mcherry"),
    "zymYPET" = str_detect(Naam, "ymypet-t2a-mtq2"),
  "mNeongreen (as GFP)" = str_detect(Naam, "mneongreen-T2A-mCherry"),
  "ymScarletI" = str_detect(Naam, "ymscarleti-t2a-mtq2"),
  "tdtomato" = str_detect(Naam, "tdtomato-T2A-mTq2"),
  "mRuby2" = str_detect(Naam, "mRuby2-t2a-mTq2"),
  "mTFP" = str_detect(Naam, "mTFP-T2A-mCherry"),
  "mCherry" = str_detect(Naam, "mcherry-t2a-mtq2"),
  "yoeCFP" = str_detect(Naam, "yoeCFP-T2A-mCherry"),
  "yomCherry" = str_detect(Naam, "yomCherry-t2a-mTq2"),
  "eCFP" = str_detect(Naam, "eCFP-t2a-mcherry"),
  "yotagRFPT" = str_detect(Naam, "yotagRFPt-T2A-mTq2"),
  "tagRFPT" = str_detect(Naam, "tagRFPT-T2A-mTq2"),
  "tagRFP" = str_detect(Naam, "tagRFP-t2a-mtq2"),
  "mCitrine" = str_detect(Naam, "mcitrine_t2a_mtq2"),
  "mVenus" = str_detect(Naam, "mVenus-t2a-mtq2"),
  "sYFP2" = str_detect(Naam, "sYFP2-t2a-mtq2"),
  "tdTomato" = str_detect(Naam, "tdtomato-t2a-mtq2_"),
  "yeVenus" = str_detect(Naam, "yevenus-t2a-mtq2"),
  "YPET" = str_detect(Naam, "YPET-T2A-mTq2"),
  "eGFP" = str_detect(Naam, "eGFP-T2A-mCherry"),
  "mClover" = str_detect(Naam, "mclover-t2a-mtq2"),
  "mko2" = str_detect(Naam, "mko2"),
  "mkok" = str_detect(Naam, "mkok"),
  "mScarletI" = str_detect(Naam, "mScarletI-T2A-mTq2"),
  "mScarlet" = str_detect(Naam, "mScarlet-T2A-mTq2"),
  "yosfGFP" = str_detect(Naam, "yosfGFP-T2A-mCherry"),
  "sGFP2" = str_detect(Naam, "sgfp2-t2a-mcherry"),
  "mKate2" = str_detect(Naam, "mkate2-t2a-mtq2"),
    .method = "first",
  .default = 5555
))

#get mean values and SD
combined5<- combined4 %>% 
  group_by(X, Naam2, Cell) %>% 
  summarise_at("Fluorescence_norm", funs(mean,sd))

colnames(combined5)[1] <- "msec_exposure"          #change column headers to the correct name
colnames(combined5)[2] <- "FP"          #change column headers to the correct name
colnames(combined5)[3] <- "Cell"          #change column headers to the correct name
colnames(combined5)[4] <- "mean_normFluorescence"          #change column headers to the correct name


#get normalized fluorescence from last timepoint to see how photostable the FP is
photostability <- combined5%>% 
  group_by(FP, Cell) %>% 
  filter(msec_exposure == 36000)


colnames(photostability)[4] <- "lowest_fluorescence" 

# add photostability value as column to dataframe
combined5 <- left_join(combined5, photostability, by = c("FP", "Cell"))
combined5[5] <- NULL
colnames(combined5)[7] <- "SD_lowest_fluorescence"          #change column headers to the correct name
colnames(combined5)[1] <- "msec_exposure"          #change column headers to the correct name

# add spectral class
photostability <-
  photostability%>% 
  mutate(FP_color = case_when(FP == "ymVenus" ~ "YFP",
                              FP == "ymNeongreen (as GFP)" ~ "GFP", 
                              FP == "ymTq2" ~ "CFP", 
                              FP == "zymYPET" ~ "YFP", 
                              FP == "ymScarletI" ~ "RFP", 
                              FP == "ytdtomato" ~ "RFP", 
                              FP == "ymNeongreen (as YFP)" ~ "YFP",
                              FP == "yoeGFP" ~ "GFP",
                              FP == "mRuby2" ~ "RFP",
                              FP == "mTFP" ~ "CFP",
                              FP == "mCherry" ~ "RFP",
                              FP == "tagRFPT" ~ "RFP",
                              FP == "yoeCFP" ~ "CFP",
                              FP == "yomCherry" ~ "RFP",
                              FP == "yotagRFPT" ~ "RFP",
                              FP == "eCFP" ~ "CFP",
                              FP == "mCitrine" ~ "YFP",
                              FP == "mVenus" ~ "YFP",
                              FP == "sYFP2" ~ "YFP",
                              FP == "tagRFP" ~ "RFP",
                              FP == "tdTomato" ~ "RFP",
                              FP == "yeVenus" ~ "YFP",
                              FP == "YPET" ~ "YFP",
                              FP == "eGFP" ~ "GFP",
                              FP == "mClover" ~ "YFP",
                              FP == "mko2" ~ "RFP",
                              FP == "mkok" ~ "RFP",
                              FP == "mNeongreen (as GFP)" ~ "GFP",
                              FP == "mNeongreen (as YFP)" ~ "YFP",
                              FP == "mScarletI" ~ "RFP",
                              FP == "mScarlet" ~ "RFP",
                              FP == "yosfGFP" ~ "GFP",
                              FP == "sGFP2" ~ "GFP",
                              FP == "mTq2" ~ "CFP",
                              FP == "mKate2" ~ "RFP"))

#add sample size per condition
combined4 <-
  combined4 %>% 
  group_by(Naam2) %>% 
  mutate(FP_samplesize=paste(Naam2,", n=",(n_distinct(Cell)))) %>% 
  ungroup()

combined4$FP_samplesize <- gsub(" ", "", combined4$FP_samplesize)
combined4$FP_samplesize <- gsub(",n", ", n", combined4$FP_samplesize)
combined4$FP_samplesize <- gsub("mNeongreen", "mNeongreen ", combined4$FP_samplesize)
combined4$FP_samplesize <- gsub("as", "as  ", combined4$FP_samplesize)

combined6 <- combined4%>% 
  group_by(Naam2) %>% 
  filter(X == 36000)
combined6[3] <- NULL
combined6[3] <- NULL
combined6[3] <- NULL
combined6[4] <- NULL

photostability2_errordata <- combined6 %>% 
  group_by(Naam2) %>%
  summarise_at("Fluorescence_norm", funs(mean, sd))
write.csv(photostability2_errordata, file = "Results_photostability_statistics2.csv")


# add FP family
combined6 <-
  combined6%>% 
  mutate(FP_name = case_when(Naam2 == "ymVenus" ~ "mVenus",
                              Naam2 == "ymNeongreen (as GFP)" ~ "mNeongreen (as GFP)", 
                              Naam2 == "ymTq2" ~ "mTq2", 
                              Naam2 == "zymYPET" ~ "(m)YPET", 
                              Naam2 == "ymScarletI" ~ "mScarletI", 
                              Naam2 == "ytdtomato" ~ "tdTomato", 
                              Naam2 == "ymNeongreen (as YFP)" ~ "mNeongreen (as YFP)",
                              Naam2 == "mVenus" ~ "mVenus",
                              Naam2 == "tdTomato" ~ "tdTomato",
                              Naam2 == "YPET" ~ "(m)YPET",
                              Naam2 == "mNeongreen (as GFP)" ~ "mNeongreen (as GFP)",
                              Naam2 == "mNeongreen (as YFP)" ~ "mNeongreen (as YFP)",
                              Naam2 == "mScarletI" ~ "mScarletI",
                              Naam2 == "mTq2" ~ "mTq2"))

# function for computing quartiles en 0.05-0.95 range of datapoints
boxstats <- function(x) {
  r <- quantile(x, probs = c(0.05, 0.25, 0.5, 0.75, 0.95))
  names(r) <- c("ymin", "lower", "middle", "upper", "ymax")
  r
}

fraction_bleached <- ggplot(combined6, aes(y=Fluorescence_norm, x=FP_samplesize, fill=FP_samplesize))+   geom_jitter(alpha=0.12, width=0.15) + stat_summary(fun.data = boxstats, geom = "boxplot", alpha=0.75, lwd=0.8, fatten=1, position=position_dodge(width=0.98))  +   theme_bw() + labs(title = titel)+ theme(plot.title = element_text(hjust = 0.5), plot.subtitle = element_text(hjust = 0.5)) +  labs(x=TextatXaxis,y=TextatYaxix)  + theme(legend.position="none")
fraction_bleached

fraction_bleached2 <- fraction_bleached + facet_grid(FP_name~., scales = "free", space = "free") + coord_flip() + scale_y_continuous(breaks=c(1, 0.8, 0.6, 0.4)) +  theme(strip.background = element_rect(fill="transparent", color="transparent")) + theme( strip.text.x = element_text(size = 16),
                                                                                                                                                                                                             strip.text = element_text(size=16),
                                                                                                                                                                                                             axis.text = element_text( size = 15 ),
                                                                                                                                                                                                             axis.text.x = element_text( size = 15 ),
                                                                                                                                                                                                             axis.text.y = element_text( size = 13 ),
                                                                                                                                                                                                             axis.title = element_text( size = 15),
                                                                                                                                                                                                             plot.title = element_text(size=24),
                                                                                                                                                                                                             plot.subtitle = element_text(size=18),
                                                                                                                                                                                                             legend.position="none") 
fraction_bleached2
