library(data.table)
library(tidyr)
library(dplyr)
library(gtools)
library(stringr)
library(magrittr)
titel <- "Intrinsic (practical) brightness of yFPs"
ondertitel1 <- 'Grown on glucose' #ondertitel 1
ondertitel2 <- 'W303-1A, Grown on glucose'                   #ondertitel2: wat moet er nog na de tekst "x samples" komen?
TextatXaxis <- ""   #which label should the X axis have?
TextatYaxix <- "interest FP : control FP \n fluorescence ratio" #which label should the y axis have?
dag <- '1'   #which day/replicate is this?

#import data
wd <<- choose.dir()     #set input folder
setwd(wd)              #set input folder
filelist = list.files(pattern = "results.*.txt")       #make a list with all the txtfiles in a folder
datalist = lapply(filelist, function(x)read.table(x, sep="\t", header=T)) 
combined = do.call("smartbind", datalist) 

# change dataframe correctly
combined2 <- gather(combined, Name, Fluorescence, starts_with("Mean")) #change format of the dataframe 
colnames(combined2)[4] <- "Fluorescence"    #change column headers to the correct name
colnames(combined2)[1] <- "Channel"          #change column headers to the correct name
colnames(combined2)[3] <- "Cell"             #change column headers to the correct name

#unique ID, so you won't get the same identifier (cell number) when using multiple images for 1 FP
combined2$uniqueID = paste(combined2$Label, combined2$Cell, sep="_")
combined2$Label <- NULL
combined2$Cell <- NULL

combined3 <- spread(combined2, Channel, Fluorescence)
combined3 <- na.omit(combined3)    #remove cells which do not have fluorescence value

#change FP name
library(mosaic)
combined3 <- mutate(combined3, uniqueID = derivedFactor(
  "yemVenus-T2A-mTq2" = str_detect(uniqueID, "yemvenus-t2a-mtq2"),
  "ymNeongreen-T2A-mtq2" = str_detect(uniqueID, "ymneongreen-t2a-mtq2"),
  "ymYPET-T2A-mtq2" = str_detect(uniqueID, "ymypet-t2a-mtq2"),
  "ymNeongreen-T2A-mCherry" = str_detect(uniqueID, "ymneongreen-t2a-mcherry"),
  "ymScarletI-T2A-mTq2" = str_detect(uniqueID, "ymscarleti-t2a-mtq2"),
  "ytdtomato-T2A-mTq2" = str_detect(uniqueID, "ytdtomato-t2a-mtq2"),
  "ymTq2-T2A-mCherry" = str_detect(uniqueID, "ymtq2-t2a-mcherry"),
            .method = "first",
  .default = 5555
))

combined3 <- mutate(combined3, Naam2 = derivedFactor(
  "ymVenus" = str_detect(uniqueID, "yemVenus-T2A-mTq2"),
  "ymYPET" = str_detect(uniqueID, "ymYPET-T2A-mtq2"),
  "ymScarletI" = str_detect(uniqueID, "ymScarletI-T2A-mTq2"),
  "yomCherry" = str_detect(uniqueID, "yomCherry-T2A-mTq2"),
    "ytdtomato" = str_detect(uniqueID, "tdtomato-T2A-mTq2"),
  "ymNeongreen (as GFP)" = str_detect(uniqueID, "ymNeongreen-T2A-mCherry"),
  "ymNeongreen (as YFP)" = str_detect(uniqueID, "ymNeongreen-T2A-mtq2"),
    "ymTq2" = str_detect(uniqueID, "ymTq2-T2A-mCherry"),
  
  .method = "first",
  .default = 5555
))

#change column names to correct channel names
colnames(combined3)[2] <- "Channel1"
colnames(combined3)[3] <- "Channel2"
colnames(combined3)[4] <- "Channel3"
colnames(combined3)[5] <- "Channel4"
colnames(combined3)[6] <- "Channel5"



#calculate brightness ratio with control FP
combined4 <- combined3
combined4 <-
  combined4 %>% 
  mutate(ratio = case_when(uniqueID == "yemVenus-T2A-mTq2" ~ (combined3$Channel2/combined3$Channel4),
                           uniqueID == "yoeGFP-T2A-mCherry" ~ (combined3$Channel3/combined3$Channel1),
                           uniqueID == "ymNeongreen-T2A-mtq2" ~ (combined3$Channel3/combined3$Channel4), 
                           uniqueID == "ymYPET-T2A-mtq2" ~ (combined3$Channel2/combined3$Channel4), 
                           uniqueID == "ymNeongreen-T2A-mCherry" ~ (combined3$Channel3/combined3$Channel1),
                           uniqueID == "ymScarletI-T2A-mTq2" ~ (combined4$Channel1/combined3$Channel4),
                           uniqueID == "ytdtomato-T2A-mTq2" ~ (combined4$Channel1/combined3$Channel4),
                           uniqueID == "ymTq2-T2A-mCherry" ~ (combined4$Channel4/combined3$Channel1)))
#add spectral class
combined4 <-
  combined4 %>% 
  mutate(FP_color = case_when(uniqueID == "yemVenus-T2A-mTq2" ~ "YFP",
                              uniqueID == "ymNeongreen-T2A-mtq2" ~ "YFP", 
                              uniqueID == "ymYPET-T2A-mtq2" ~ "YFP", 
                              uniqueID == "ymScarletI-T2A-mTq2" ~ "RFP", 
                              uniqueID == "ytdtomato-T2A-mTq2" ~ "RFP", 
                              uniqueID == "ymTq2-T2A-mCherry" ~ "CFP", 
                              uniqueID == "ymNeongreen-T2A-mCherry" ~ "GFP"))

require(data.table)
require(dplyr)
detach(package:plyr)
library(dplyr)
library(plotrix)
#add sample size per condition
combined5 <-
  combined4 %>% 
  group_by(uniqueID) %>% 
  mutate(FP_samplesize=paste(Naam2,", n=",length(uniqueID))) %>% 
  ungroup()


combined5$FP_samplesize <- gsub(" ", "", combined5$FP_samplesize)
combined5$FP_samplesize <- gsub(",n", ", n", combined5$FP_samplesize)
combined5$FP_samplesize <- gsub("mNeongreen", "mNeongreen ", combined5$FP_samplesize)
combined5$FP_samplesize <- gsub("as", "as  ", combined5$FP_samplesize)
combined5$day_replicate <- dag

#calculate coefficient of variation
errordata <- combined5 %>% 
  group_by(uniqueID) %>% 
  select(ratio) %>% 
  summarise_all(funs(mean,sd)) %>% 
  mutate (relative_sd=sd/mean)

# export brightness statistics
write.table(errordata, file = paste("Results_brightness_statistics", titel, ".txt"),  sep="\t", row.names = T)
write.table(combined5, file = "Results_brightness_all_cells.txt",  sep="\t", row.names = T)

# function for plotting 0.05-0.95 datapoints in boxplot
boxstats <- function(x) {
  r <- quantile(x, probs = c(0.05, 0.25, 0.5, 0.75, 0.95))
  names(r) <- c("ymin", "lower", "middle", "upper", "ymax")
  r
}

# plot data
library(ggplot2)
library(ggpmisc)
library(gridBase)
library(grid)
plot <- ggplot(combined5, aes(y=ratio, x=FP_samplesize, fill=FP_samplesize))  +   geom_jitter(alpha=0.05, size= 1) + stat_summary(fun.data = boxstats, geom = "boxplot", alpha=0.75, lwd=0.8, fatten=1)  +   theme_bw() + labs(title = titel, subtitle = ondertitel2)+ theme(plot.title = element_text(hjust = 0.5), plot.subtitle = element_text(hjust = 0.5)) +  labs(x=TextatXaxis,y=TextatYaxix) + theme(axis.text.x = element_text(angle = 60, hjust = 1)) + theme(legend.position="none") + scale_y_continuous(breaks=c(0,1,2,3,4,5,6))
plot
plot2 <- plot + facet_grid(.~FP_color, scales = "free", space = "free")  +  theme(strip.background = element_rect(fill="transparent", color="transparent")) + theme( strip.text.x = element_text(size = 16), axis.text = element_text( size = 15 ), axis.text.x = element_text( size = 15 ), axis.title = element_text( size = 15), plot.title = element_text(size=24), plot.subtitle = element_text(size=18), legend.position="none") 
plot2


plot_flipped <- ggplot(combined5, aes(y=ratio, x=FP_samplesize, fill=FP_samplesize)) + coord_flip() +   geom_jitter(alpha=0.05, size= 1) + stat_summary(fun.data = boxstats, geom = "boxplot", alpha=0.75, lwd=0.8, fatten=1)  +   theme_bw() + labs(title = titel, subtitle = ondertitel2)+ theme(plot.title = element_text(hjust = 0.5), plot.subtitle = element_text(hjust = 0.5)) +  labs(x=TextatXaxis,y=TextatYaxix)  + theme(legend.position="none") + scale_y_continuous(breaks=c(0,1,2,3,4,5,6))
plot_flipped

plot2_flipped <- plot_flipped + facet_grid(FP_color~., scales = "free", space = "free")  +  theme(strip.background = element_rect(fill="transparent", color="transparent")) + theme( strip.text.x = element_text(size = 16),
                                                                                                                                                                                     axis.text = element_text( size = 15 ),
                                                                                                                                                                                     axis.text.x = element_text( size = 15 ),
                                                                                                                                                                                     axis.title = element_text( size = 15),
                                                                                                                                                                                     plot.title = element_text(size=24),
                                                                                                                                                                                     plot.subtitle = element_text(size=18),
                                                                                                                                                                                     legend.position="none") 
plot2_flipped 



