library(data.table)
library(tidyr)
library(dplyr)
library(gtools)
library(stringr)
library(magrittr)
titel <- "Intrinsic (practical) brightness of yFPs"
ondertitel1 <- 'Grown on glucose' #ondertitel 1
ondertitel2 <- 'W303-1A, Grown on glucose'                   #ondertitel2: wat moet er nog na de tekst "x samples" komen?
TextatXaxis <- ""   #which label should the X axis have?
TextatYaxix <- "interest FP : control FP \n fluorescence ratio" #which label should the y axis have?
dag <- '3'   #which day/replicate is this?


# import data
wd <<- choose.dir()     #set input folder
setwd(wd)              #set input folder
filelist = list.files(pattern = "results.*.txt")       #make a list with all the txtfiles in a folder
datalist = lapply(filelist, function(x)read.table(x, sep="\t", header=T)) 
combined = do.call("smartbind", datalist) 

combined2 <- gather(combined, Name, Fluorescence, starts_with("Mean")) #change format of the dataframe 
colnames(combined2)[4] <- "Fluorescence"    #change column headers to the correct name
colnames(combined2)[1] <- "Channel"          #change column headers to the correct name
colnames(combined2)[3] <- "Cell"             #change column headers to the correct name

# create unique ID, so you can discriminate cellnumber between different images
combined2$uniqueID = paste(combined2$Label, combined2$Cell, sep="_")
combined2$Label <- NULL
combined2$Cell <- NULL

# change dataframe
combined3 <- spread(combined2, Channel, Fluorescence)
combined3 <- na.omit(combined3)    #remove cells which do not have fluorescence value

#add FP names
library(mosaic)
combined3 <- mutate(combined3, uniqueID = derivedFactor(
  "yotagRFPt-T2A-mTq2" = str_detect(uniqueID, "yotagRFPT-T2A-mTq2"),
  "yemVenus-T2A-mTq2" = str_detect(uniqueID, "yemVenus-T2A-mTq2"),
  "yoeGFP-T2A-mCherry" = str_detect(uniqueID, "yoeGFP-T2A-mCherry"),
    "ymNeongreen-T2A-mtq2" = str_detect(uniqueID, "ymNeongreen-t2a-mtq2"),
  "ymYPET-T2A-mtq2" = str_detect(uniqueID, "ymYPET-t2a-mtq2"),
  "ymNeongreen-T2A-mCherry" = str_detect(uniqueID, "ymNeongreen-T2A-mCherry"),
  "ymScarletI-T2A-mTq2" = str_detect(uniqueID, "ymScarletI-T2A-mTq2"),
  "ytdtomato-T2A-mTq2" = str_detect(uniqueID, "ytdtomato-T2A-mTq2"),
  "mRuby2-T2A-mTq2" = str_detect(uniqueID, "mRuby2-t2a-mTq2"),
  "mTFP-T2A-mCherry" = str_detect(uniqueID, "mTFP-T2A-mCherry"),
  "yomCherry-T2A-mTq2" = str_detect(uniqueID, "yomCherry-T2A-mTq2"),
    "mCherry-T2A-mTq2" = str_detect(uniqueID, "mcherry-t2a-mtq2"),
  "tagRFPT-T2A-mTq2" = str_detect(uniqueID, "tagRFPT-t2a-mtq2"),
  "yoeCFP-T2A-mCherry" = str_detect(uniqueID, "yoeCFP-T2A-mCherry"),
  "eCFP-T2A-mCherry" = str_detect(uniqueID, "eCFP-t2a-mcherry"),
  "mCitrine-T2A-mTq2" = str_detect(uniqueID, "mCitrine-t2a-mtq2"),
  "mNeongreen-T2A-mTq2" = str_detect(uniqueID, "mNeongreen-t2a-mtq2"),
  "mVenus-T2A-mTq2" = str_detect(uniqueID, "mVenus-t2a-mCherry"),
  "sYFP2-T2A-mTq2" = str_detect(uniqueID, "sYFP2-t2a-mtq2"),
  "tagRFP-T2A-mTq2" = str_detect(uniqueID, "tagRFP-t2a-mTq2"),
  "tdTomato-T2A-mTq2" = str_detect(uniqueID, "tdtomato-t2a-mtq2"),
  "yeVenus-T2A-mTq2" = str_detect(uniqueID, "yeVenus-T2A-mTq2"),
  "YPET-T2A-mTq2" = str_detect(uniqueID, "YPET-t2a-mtq2"),
  "eGFP-T2A-mCherry" = str_detect(uniqueID, "eGFP-t2a-mcherry"),
  "mClover-T2A-mTq2" = str_detect(uniqueID, "mClover-T2A-mTq2"),
  "mko2-T2A-mTq2" = str_detect(uniqueID, "mko2-T2A-mTq2"),
  "mkok-T2A-mTq2" = str_detect(uniqueID, "mkokappa-t2a-mtq2"),
  "mNeongreen-T2A-mCherry" = str_detect(uniqueID, "mNeongreen-T2A-mCherry"),
  "mScarletI-T2A-mTq2" = str_detect(uniqueID, "mscarleti-t2a-mtq2"),
  "mScarlet-T2A-mTq2" = str_detect(uniqueID, "mScarlet-t2a-mTq2"),
  "yosfGFP-T2A-mCherry" = str_detect(uniqueID, "yosfGFP-T2A-mCherry"),
  "sGFP2-T2A-mCherry" = str_detect(uniqueID, "sGFP2-T2A-mCherry"),
  "mTq2-T2A-mcherry" = str_detect(uniqueID, "mTq2-t2a-mcherry"),
  "mkate2-T2A-mTq2" = str_detect(uniqueID, "mkate2-T2A-mTq2"),
          .method = "first",
  .default = 5555
))

combined3 <- mutate(combined3, Naam2 = derivedFactor(
  "yotagRFPT" = str_detect(uniqueID, "yotagRFPt-T2A-mTq2"),
    "yemVenus" = str_detect(uniqueID, "yemVenus-T2A-mTq2"),
  "yoeGFP" = str_detect(uniqueID, "yoeGFP-T2A-mCherry"),
  "ymYPET" = str_detect(uniqueID, "ymYPET-t2a-mtq2"),
  "ymScarletI" = str_detect(uniqueID, "ymScarletI-T2A-mTq2"),
  "yomCherry" = str_detect(uniqueID, "yomCherry-T2A-mTq2"),
    "ytdtomato" = str_detect(uniqueID, "tdtomato-T2A-mTq2"),
  "mRuby2" = str_detect(uniqueID, "mRuby2-T2A-mTq2"),
  "mTFP" = str_detect(uniqueID, "mTFP-T2A-mCherry"),
  "mCherry" = str_detect(uniqueID, "mCherry-T2A-mTq2"),
  "tagRFPT" = str_detect(uniqueID, "tagRFPT-T2A-mTq2"),
  "yoeCFP" = str_detect(uniqueID, "yoeCFP-T2A-mCherry"),
  "yotagRFPt" = str_detect(uniqueID, "yotagRFPt-T2A-mTq2"),
  "eCFP" = str_detect(uniqueID, "eCFP-T2A-mCherry"),
  "mCitrine" = str_detect(uniqueID, "mCitrine-T2A-mTq2"),
  "mNeongreen (as YFP)" = str_detect(uniqueID, "mNeongreen-T2A-mTq2"),
  "mVenus" = str_detect(uniqueID, "mVenus-T2A-mTq2"),
  "sYFP2" = str_detect(uniqueID, "sYFP2-T2A-mTq2"),
  "tagRFP" = str_detect(uniqueID, "tagRFP-T2A-mTq2"),
  "tdTomato" = str_detect(uniqueID, "tdTomato-T2A-mTq2"),
  "yeVenus" = str_detect(uniqueID, "yeVenus-T2A-mTq2"),
  "YPET" = str_detect(uniqueID, "YPET-T2A-mTq2"),
  "eGFP" = str_detect(uniqueID, "eGFP-T2A-mCherry"),
  "mClover" = str_detect(uniqueID, "mClover-T2A-mTq2"),
  "mko2" = str_detect(uniqueID, "mko2-T2A-mTq2"),
  "mkok" = str_detect(uniqueID, "mkok-T2A-mTq2"),
  "mNeongreen (as GFP)" = str_detect(uniqueID, "mNeongreen-T2A-mCherry"),
  "mScarletI" = str_detect(uniqueID, "mScarletI-T2A-mTq2"),
  "mScarlet" = str_detect(uniqueID, "mScarlet-T2A-mTq2"),
  "yosfGFP" = str_detect(uniqueID, "yosfGFP-T2A-mCherry"),
  "sGFP2" = str_detect(uniqueID, "sGFP2-T2A-mCherry"),
  "mTq2" = str_detect(uniqueID, "mTq2-T2A-mcherry"),
  "mkate2" = str_detect(uniqueID, "mkate2-T2A-mTq2"),
  .method = "first",
  .default = 5555
))

# add channel numbers

colnames(combined3)[2] <- "Channel1"
colnames(combined3)[3] <- "Channel2"
colnames(combined3)[4] <- "Channel3"
colnames(combined3)[5] <- "Channel4"

#calculate brightness ratios with control FP
combined4 <- combined3
combined4 <-
  combined4 %>% 
  mutate(ratio = case_when(uniqueID == "mRuby2-T2A-mTq2" ~ (combined3$Channel3/combined3$Channel2),
                           uniqueID == "yoeGFP-T2A-mCherry" ~ (combined3$Channel4/combined3$Channel3),
                           uniqueID == "mTFP-T2A-mCherry" ~ (combined3$Channel2/combined3$Channel3),
                           uniqueID == "mCherry-T2A-mTq2" ~ (combined3$Channel3/combined3$Channel2),
                           uniqueID == "tagRFPT-T2A-mTq2" ~ (combined3$Channel3/combined3$Channel2),
                           uniqueID == "yoeCFP-T2A-mCherry" ~ (combined3$Channel2/combined3$Channel3),
                           uniqueID == "yomCherry-T2A-mTq2" ~ (combined3$Channel3/combined3$Channel2),
                           uniqueID == "yotagRFPt-T2A-mTq2" ~ (combined3$Channel3/combined3$Channel2),
                           uniqueID == "eCFP-T2A-mCherry" ~ (combined3$Channel2/combined3$Channel3),
                           uniqueID == "mCitrine-T2A-mTq2" ~ (combined3$Channel1/combined3$Channel2),
                           uniqueID == "mVenus-T2A-mTq2" ~ (combined3$Channel1/combined3$Channel2),
                           uniqueID == "sYFP2-T2A-mTq2" ~ (combined3$Channel1/combined3$Channel2),
                           uniqueID == "tagRFP-T2A-mTq2" ~ (combined3$Channel3/combined3$Channel2),
                           uniqueID == "tdTomato-T2A-mTq2" ~ (combined3$Channel3/combined3$Channel2),
                           uniqueID == "yeVenus-T2A-mTq2" ~ (combined3$Channel1/combined3$Channel2),
                           uniqueID == "YPET-T2A-mTq2" ~ (combined3$Channel1/combined3$Channel2),
                           uniqueID == "eGFP-T2A-mCherry" ~ (combined3$Channel4/combined3$Channel3),
                           uniqueID == "mClover-T2A-mTq2" ~ (combined3$Channel1/combined3$Channel2),
                           uniqueID == "mko2-T2A-mTq2" ~ (combined3$Channel1/combined3$Channel2),
                           uniqueID == "mkok-T2A-mTq2" ~ (combined3$Channel1/combined3$Channel2),
                           uniqueID == "mNeongreen-T2A-mCherry" ~ (combined3$Channel4/combined3$Channel3),
                           uniqueID == "mNeongreen-T2A-mTq2" ~ (combined3$Channel1/combined3$Channel2),
                           uniqueID == "mScarletI-T2A-mTq2" ~ (combined3$Channel3/combined3$Channel2),
                           uniqueID == "mScarlet-T2A-mTq2" ~ (combined3$Channel3/combined3$Channel2),
                           uniqueID == "yosfGFP-T2A-mCherry" ~ (combined3$Channel4/combined3$Channel3),
                           uniqueID == "sGFP2-T2A-mCherry" ~ (combined3$Channel4/combined3$Channel3),
                           uniqueID == "mTq2-T2A-mcherry" ~ (combined3$Channel2/combined3$Channel3),
                           uniqueID == "mkate2-T2A-mTq2" ~ (combined3$Channel3/combined3$Channel2)))
combined4 <-
  combined4 %>% 
  mutate(FP_color = case_when(uniqueID == "yemVenus-T2A-mTq2" ~ "YFP",
                              uniqueID == "ymNeongreen-T2A-mTq2" ~ "YFP", 
                              uniqueID == "ymYPET-T2A-mTq2" ~ "YFP", 
                              uniqueID == "ymScarletI-T2A-mTq2" ~ "RFP", 
                              uniqueID == "ytdtomato-T2A-mTq2" ~ "RFP", 
                              uniqueID == "ymNeongreen-T2A-mCherry" ~ "GFP",
                              uniqueID == "yoeGFP-T2A-mCherry" ~ "GFP",
                              uniqueID == "mRuby2-T2A-mTq2" ~ "RFP",
                              uniqueID == "mTFP-T2A-mCherry" ~ "CFP",
                              uniqueID == "mCherry-T2A-mTq2" ~ "RFP",
                              uniqueID == "tagRFPT-T2A-mTq2" ~ "RFP",
                              uniqueID == "yoeCFP-T2A-mCherry" ~ "CFP",
                              uniqueID == "yomCherry-T2A-mTq2" ~ "RFP",
                              uniqueID == "yotagRFPt-T2A-mTq2" ~ "RFP",
                              uniqueID == "eCFP-T2A-mCherry" ~ "CFP",
                              uniqueID == "mCitrine-T2A-mTq2" ~ "YFP",
                              uniqueID == "mVenus-T2A-mTq2" ~ "YFP",
                              uniqueID == "sYFP2-T2A-mTq2" ~ "YFP",
                              uniqueID == "tagRFP-T2A-mTq2" ~ "RFP",
                              uniqueID == "tdTomato-T2A-mTq2" ~ "RFP",
                              uniqueID == "yeVenus-T2A-mTq2" ~ "YFP",
                              uniqueID == "YPET-T2A-mTq2" ~ "YFP",
                              uniqueID == "eGFP-T2A-mCherry" ~ "GFP",
                              uniqueID == "mClover-T2A-mTq2" ~ "YFP",
                              uniqueID == "mko2-T2A-mTq2" ~ "RFP",
                              uniqueID == "mkok-T2A-mTq2" ~ "RFP",
                              uniqueID == "mNeongreen-T2A-mCherry" ~ "GFP",
                              uniqueID == "mNeongreen-T2A-mTq2" ~ "YFP",
                              uniqueID == "mScarletI-T2A-mTq2" ~ "RFP",
                              uniqueID == "mScarlet-T2A-mTq2" ~ "RFP",
                              uniqueID == "yosfGFP-T2A-mCherry" ~ "GFP",
                              uniqueID == "sGFP2-T2A-mCherry" ~ "GFP",
                              uniqueID == "mTq2-T2A-mcherry" ~ "CFP",
                              uniqueID == "mkate2-T2A-mTq2" ~ "RFP"))
                              

require(data.table)
require(dplyr)
detach(package:plyr)
library(dplyr)
library(plotrix)
#add sample size per condition
combined5 <-
  combined4 %>% 
  group_by(uniqueID) %>% 
  mutate(FP_samplesize=paste(Naam2,", n=",length(uniqueID))) %>% 
  ungroup()


combined5$FP_samplesize <- gsub(" ", "", combined5$FP_samplesize)
combined5$FP_samplesize <- gsub(",n", ", n", combined5$FP_samplesize)
combined5$FP_samplesize <- gsub("mNeongreen", "mNeongreen ", combined5$FP_samplesize)
combined5$FP_samplesize <- gsub("as", "as  ", combined5$FP_samplesize)
combined5$day_replicate <- dag

# coefficient of variation of 1 day
errordata <- combined5 %>% 
  group_by(uniqueID) %>% 
  select(ratio) %>% 
  summarise_all(funs(mean,sd)) %>% 
  mutate (relative_sd=sd/mean)

# export brightness statistics
write.table(errordata, file = paste("Results_brightness_statistics", titel, ".txt"),  sep="\t", row.names = T)
write.table(combined5, file = "Results_brightness_all_cells.txt",  sep="\t", row.names = T)

# function for plotting 0.05-0.95 datapoints in boxplot
boxstats <- function(x) {
  r <- quantile(x, probs = c(0.05, 0.25, 0.5, 0.75, 0.95))
  names(r) <- c("ymin", "lower", "middle", "upper", "ymax")
  r
}

# plot data
library(ggplot2)
library(ggpmisc)
library(gridBase)
library(grid)
plot <- ggplot(combined5, aes(y=ratio, x=FP_samplesize, fill=FP_samplesize))  +   geom_jitter(alpha=0.05, size= 1) + stat_summary(fun.data = boxstats, geom = "boxplot", alpha=0.75, lwd=0.8, fatten=1)  +   theme_bw() + labs(title = titel, subtitle = ondertitel2)+ theme(plot.title = element_text(hjust = 0.5), plot.subtitle = element_text(hjust = 0.5)) +  labs(x=TextatXaxis,y=TextatYaxix) + theme(axis.text.x = element_text(angle = 60, hjust = 1)) + theme(legend.position="none") + scale_y_continuous(breaks=c(0,1,2,3,4,5,6))
plot
plot2 <- plot + facet_grid(.~FP_color, scales = "free", space = "free")  +  theme(strip.background = element_rect(fill="transparent", color="transparent")) + theme( strip.text.x = element_text(size = 16), axis.text = element_text( size = 15 ), axis.text.x = element_text( size = 15 ), axis.title = element_text( size = 15), plot.title = element_text(size=24), plot.subtitle = element_text(size=18), legend.position="none") 
plot2


plot_flipped <- ggplot(combined5, aes(y=ratio, x=FP_samplesize, fill=FP_samplesize)) + coord_flip() +   geom_jitter(alpha=0.05, size= 1) + stat_summary(fun.data = boxstats, geom = "boxplot", alpha=0.75, lwd=0.8, fatten=1)  +   theme_bw() + labs(title = titel, subtitle = ondertitel2)+ theme(plot.title = element_text(hjust = 0.5), plot.subtitle = element_text(hjust = 0.5)) +  labs(x=TextatXaxis,y=TextatYaxix)  + theme(legend.position="none") + scale_y_continuous(breaks=c(0,1,2,3,4,5,6))
plot_flipped

plot2_flipped <- plot_flipped + facet_grid(FP_color~., scales = "free", space = "free")  +  theme(strip.background = element_rect(fill="transparent", color="transparent")) + theme( strip.text.x = element_text(size = 16),
                                                                                                                                                                                     axis.text = element_text( size = 15 ),
                                                                                                                                                                                     axis.text.x = element_text( size = 15 ),
                                                                                                                                                                                     axis.title = element_text( size = 15),
                                                                                                                                                                                     plot.title = element_text(size=24),
                                                                                                                                                                                     plot.subtitle = element_text(size=18),
                                                                                                                                                                                     legend.position="none") 
plot2_flipped 



