library(data.table)
library(tidyr)
library(dplyr)
library(gtools)
library(stringr)
library(dplyr)
library(magrittr)
library(plotrix)
titel <- "W303-1A FPs"
ondertitel1 <- 'pH curves, solid lines=yFP, dashed=FP' #subtitle1
ondertitel2 <- ''                   #subtitle1
TextatXaxis <- "pH"   #which label should the X axis have?
TextatYaxix <- "Normalized fluorescence" #which label should the y axis have?

#imoprt data
wd <<- choose.dir()     #set input folder
setwd(wd)              #set input folder
filelist = list.files(pattern = "Results.*.txt")       #make a list with all the txtfiles in a folder
datalist = lapply(filelist, function(x)read.table(x, sep="\t", header=T)) 
combined = do.call("smartbind", datalist) 

combined2 <- gather(combined, Name, Fluorescence, starts_with("Mean")) #change format of the dataframe 
combined2 <- na.omit(combined2)#change format of the dataframe 
colnames(combined2)[3] <- "Well"             #change column headers to the correct name
colnames(combined2)[4] <- "Fluorescence"    #change column headers to the correct name
colnames(combined2)[2] <- "Naam"          #change column headers to the correct name
colnames(combined2)[1] <- "pH"          #change column headers to the correct name

detach(plyr)
library(dplyr)
library(plotrix)
#get mean values, SD and SE
errordata <- combined2 %>% 
  group_by(pH, Naam) %>% 
  summarise_all(funs(mean,sd,std.error))

errordata[3] <- NULL 
errordata[4] <- NULL 
errordata[5] <- NULL 

#data is already corrected for autofluorescence and normalized, so change names correctly
names(errordata)[3] <- "Fluorescence_norm_mean"
names(errordata)[4] <- "Fluorescence_norm_sd"
names(errordata)[5] <- "Fluorescence_norm_std.error"

#add FP name
library(mosaic)
errordata <- mutate(errordata, Naam = derivedFactor(
  "ymTq2" = str_detect(Naam, "ymtq2"),
    "ymVenus" = str_detect(Naam, "ymvenus"),
  "mNeongreen" = str_detect(Naam, "neongreen-t2a-mtq2"),
  "ymNeongreen" = str_detect(Naam, "ymneongreen"),
  "ymYPET" = str_detect(Naam, "ymypet"),
  "ymScarletI" = str_detect(Naam, "ymscarleti"),
  "ytdtomato" = str_detect(Naam, "ytdtomato"),
  "mRuby2" = str_detect(Naam, "mruby 2"),
  "mTFP" = str_detect(Naam, "mtfp"),
  "yomCherry" = str_detect(Naam, "yomcherry"),
  "mCherry" = str_detect(Naam, "mcherry"),
  "yotagRFPt" = str_detect(Naam, "yotagrfpt"),
  "tagRFPT" = str_detect(Naam, "tagrfpt"),
  "yoeCFP" = str_detect(Naam, "yoecfp"),
  "eCFP" = str_detect(Naam, "ecfp"),
  "mCitrine" = str_detect(Naam, "mcitrine"),
    "mVenus" = str_detect(Naam, "mvenus"),
  "sYFP2" = str_detect(Naam, "syfp2"),
  "tagRFP" = str_detect(Naam, "tagrfp"),
  "tdTomato" = str_detect(Naam, "tdtomato"),
  "yeVenus" = str_detect(Naam, "yevenus"),
  "YPET" = str_detect(Naam, "ypet"),
  "yoeGFP" = str_detect(Naam, "yoegfp"),
  "eGFP" = str_detect(Naam, "egfp"),
  "mClover" = str_detect(Naam, "mclover"),
  "mko2" = str_detect(Naam, "mko2"),
  "mkok" = str_detect(Naam, "mkok"),
  "mScarletI" = str_detect(Naam, "mscarleti"),
  "mScarlet" = str_detect(Naam, "mscarlet"),
  "yosfGFP" = str_detect(Naam, "yosfgfp"),
  "sGFP2" = str_detect(Naam, "sgfp2"),
  "mTq2" = str_detect(Naam, "mtq2"),
  "mKate2" = str_detect(Naam, "mkate2"),
  .method = "first",
  .default = 5555
))

#add spectral class
errordata <-
  errordata %>% 
  mutate(FP_color = case_when(Naam == "ymVenus" ~ "YFP",
                              Naam == "ymNeongreen" ~ "GFP", 
                              Naam == "ymTq2" ~ "CFP", 
                              Naam == "ymYPET" ~ "YFP", 
                              Naam == "ymScarletI" ~ "RFP", 
                              Naam == "ytdtomato" ~ "RFP", 
                              Naam == "ymNeongreen" ~ "GFP",
                              Naam == "yoeGFP" ~ "GFP",
                              Naam == "mRuby2" ~ "RFP",
                              Naam == "mTFP" ~ "CFP",
                              Naam == "mCherry" ~ "RFP",
                              Naam == "tagRFPT" ~ "RFP",
                              Naam == "yoeCFP" ~ "CFP",
                              Naam == "yomCherry" ~ "RFP",
                              Naam == "yotagRFPt" ~ "RFP",
                              Naam == "eCFP" ~ "CFP",
                              Naam == "mCitrine" ~ "YFP",
                              Naam == "mVenus" ~ "YFP",
                              Naam == "sYFP2" ~ "YFP",
                              Naam == "tagRFP" ~ "RFP",
                              Naam == "tdTomato" ~ "RFP",
                              Naam == "yeVenus" ~ "YFP",
                              Naam == "YPET" ~ "YFP",
                              Naam == "eGFP" ~ "GFP",
                              Naam == "mClover" ~ "YFP",
                              Naam == "mko2" ~ "RFP",
                              Naam == "mkok" ~ "RFP",
                              Naam == "mNeongreen" ~ "GFP",
                              Naam == "mNeongreen" ~ "YFP",
                              Naam == "mScarletI" ~ "RFP",
                              Naam == "mScarlet" ~ "RFP",
                              Naam == "yosfGFP" ~ "GFP",
                              Naam == "sGFP2" ~ "GFP",
                              Naam == "mTq2" ~ "CFP",
                              Naam == "mKate2" ~ "RFP"))

#put data to another dataframe
combined2$fluorescence_norm_mean <- errordata$Fluorescence_norm_mean
combined2$fluorescence_norm_sd <- errordata$Fluorescence_norm_sd
colnames(combined2)[4] <- "Fluorescence_norm"    #change column headers to the correct name

#Hillfit
library(nls2)
library(minpack.lm)
library(nlme)
library(broom)

Hillfit_formula <- Fluorescence_norm_mean ~ Bottom + (Top-Bottom)/(1+10^((pKa-pH)*HillSlope))
fit = errordata %>% group_by(Naam) %>%
do(Hillfit = nls(Hillfit_formula, data = ., start = list(Bottom=0, Top=1, pKa=4, HillSlope=1), lower = c(0, 1, 0,0 ), upper = c(1, 1, Inf, Inf), algorithm = "port")) 
fitprediction = augment(fit, Hillfit, newdata = data.frame(pH = seq(1, 8, by=0.01)))
fitparameters = tidy(fit, Hillfit)
fitparameters <- as.data.frame(fitparameters)
capture.output(fitparameters, file = paste("fitparameters", titel, ".txt"))

# get pH50 (is 50% from the offset to 1, for example. if the offset is at 0.2, then you will get as pKa the pH value at 0.6 fluorescence of max), but absolute 50% decrease in fluorescence
library(data.table)
setDT(fitprediction, keep.rownames=TRUE, key=NULL, check.names=FALSE)
absolute_50percent_less_fluorescence <- fitprediction[, approx(.fitted,pH,xout=.5), by="Naam"]
capture.output(absolute_50percent_less_fluorescence, file = paste("absolute_50percent_less_fluorescence", titel, ".txt"))

#export parameter values of the fitting
library(plyr)
capture.output(absolute_50percent_less_fluorescence, file = paste("absolute_50percent_less_fluorescence", titel, ".txt"))

# make fitparameters correct for plotting
fitparameters2 <-  fitparameters %>%
    group_by(Naam, term) %>% 
  summarise_at("estimate", funs(mean))
fitparameters2 <- spread(fitparameters2, key =term, value=estimate)
fitparameters2 <-
  fitparameters2 %>% 
  mutate(FP_color = case_when(Naam == "ymVenus" ~ "YFP",
                              Naam == "ymNeongreen" ~ "GFP", 
                              Naam == "ymTq2" ~ "CFP", 
                              Naam == "ymYPET" ~ "YFP", 
                              Naam == "ymScarletI" ~ "RFP", 
                              Naam == "ytdtomato" ~ "RFP", 
                              Naam == "ymNeongreen" ~ "GFP",
                              Naam == "mVenus" ~ "YFP",
                              Naam == "tdTomato" ~ "RFP",
                              Naam == "yeVenus" ~ "YFP",
                              Naam == "YPET" ~ "YFP",
                              Naam == "mNeongreen" ~ "GFP",
                              Naam == "mNeongreen" ~ "YFP",
                              Naam == "mScarletI" ~ "RFP",
                              Naam == "mTq2" ~ "CFP"))

# make extra grouping to group of the same FP the mammalian and codon optimized form
errordata <-
  errordata %>% 
  mutate(FP_name = case_when(Naam == "ymVenus" ~ "mVenus",
                              Naam == "ymNeongreen" ~ "mNeongreen", 
                              Naam == "ymTq2" ~ "mTq2", 
                              Naam == "ymYPET" ~ "(m)YPET", 
                              Naam == "ymScarletI" ~ "mScarletI", 
                              Naam == "ytdtomato" ~ "tdTomato",
                             Naam == "mVenus" ~ "mVenus",
                             Naam == "mNeongreen" ~ "mNeongreen", 
                             Naam == "mTq2" ~ "mTq2", 
                             Naam == "YPET" ~ "(m)YPET", 
                             Naam == "mScarletI" ~ "mScarletI", 
                             Naam == "tdTomato" ~ "tdTomato"))
# make extra grouping to group of the same FP the mammalian and codon optimized form
fitprediction <-
  fitprediction %>% 
  mutate(FP_name = case_when(Naam == "ymVenus" ~ "mVenus",
                             Naam == "ymNeongreen" ~ "mNeongreen", 
                             Naam == "ymTq2" ~ "mTq2", 
                             Naam == "ymYPET" ~ "(m)YPET", 
                             Naam == "ymScarletI" ~ "mScarletI", 
                             Naam == "ytdtomato" ~ "tdTomato",
                             Naam == "mVenus" ~ "mVenus",
                             Naam == "mNeongreen" ~ "mNeongreen", 
                             Naam == "mTq2" ~ "mTq2", 
                             Naam == "YPET" ~ "(m)YPET", 
                             Naam == "mScarletI" ~ "mScarletI", 
                             Naam == "tdTomato" ~ "tdTomato"))
                              
library(ggpmisc)
library("RColorBrewer")
library(Hmisc)
library(extrafont)
options(java.parameters = "- Xmx2024m")
library(ggplot2)
library(svglite)
library(ggrepel)
library(wesanderson)
mycolors = c(brewer.pal(name="Dark2", n = 8), brewer.pal(name="Paired", n = 4))

#make plots
plotmean_sd <- ggplot() + geom_errorbar(data=errordata, aes(x=pH, ymin=Fluorescence_norm_mean-Fluorescence_norm_sd, ymax=Fluorescence_norm_mean+Fluorescence_norm_sd), color="black", width=.1, size=1) + theme_light() + labs(title = titel, subtitle = ondertitel1)+ theme(plot.title = element_text(hjust = 0.5), plot.subtitle = element_text(hjust = 0.5))  +  geom_point(data=errordata, aes(x=pH, y=Fluorescence_norm_mean, fill=Naam, shape=Naam), size=3, alpha=.9)  + labs(x=TextatXaxis,y=TextatYaxix) + theme(text=element_text(size=25)) + theme(legend.position="none", axis.text.y =element_text(size=24), axis.text.x =element_text(size=24)) + coord_cartesian(xlim = c(1, 8)) + scale_x_continuous(breaks = round(seq(0, 8, by = 1))) + scale_y_continuous(breaks = c(0,0.2,0.4,0.6,0.8,1)) +coord_cartesian(ylim=c(-0.1,1.1)) +  theme(legend.position = c(0.8,0.1), legend.title=element_text(size=18), legend.text=element_text(size=16)) +scale_shape_manual(values=c(21,21,23,21,21,21,21,23,23,23,23,23))
plotmean_sd
plotmean_sd2 <- plotmean_sd  +  geom_line(data=fitprediction, aes(x=pH, y=.fitted, linetype=Naam), size=1.3, alpha=0.6) + scale_linetype_manual(values=c("solid", "solid", "dashed","solid","solid","solid","solid","dashed","dashed","dashed","dashed","dashed"))

plotmean_sd2
plotmean_grids <- plotmean_sd2 + facet_wrap(~FP_name) + scale_fill_manual(values=c("#2011f4", "#ffff00","#0baa0b","#0baa0b","#ffff00","#e5110d","#e5110d","#ffff00","#e5110d","#ffff00","#e5110d","#2011f4")) +  theme_light() +  theme(strip.background = element_rect(fill="transparent", color="transparent")) + theme( strip.text.x = element_text(size = 16, color="black"),
                                                                                                                                                                                                                                                                                                  axis.text = element_text( size = 15 ),
                                                                                                                                                                                                                                                                                                  axis.text.x = element_text( size = 15 ),
                                                                                                                                                                                                                                                                                                  axis.title = element_text( size = 15),
                                                                                                                                                                                                                                                                                                  plot.title = element_text(size=24),
                                                                                                                                                                                                                                                                                                  plot.subtitle = element_text(size=18),
                                                                                                                                                                                                                                                                                                  
                                                                                                                                                                                                                                                                                                  legend.position="none")
plotmean_grids


pKa_hill_plot <- ggplot(data=fitparameters2, aes(x=pKa, y=HillSlope, fill = factor(FP_color))) + geom_point(shape=21, size=4, stroke = .7, alpha=0.65) + scale_fill_manual(values=c("#1a5def", "#25dd2b", "#e02e21", "#ffff00")) +  theme_light() + labs(title = titel, subtitle = ondertitel1)+ theme(plot.title = element_text(hjust = 0.5), plot.subtitle = element_text(hjust = 0.5)) + scale_y_continuous(limits = c(0.2, 1.3)) + labs(title = titel, subtitle = ondertitel2)+ theme(plot.title = element_text(hjust = 0.5), plot.subtitle = element_text(hjust = 0.5)) +  labs(x=TextatXaxis,y=TextatYaxix) + theme_bw()  + theme(plot.title = element_text(hjust = 0.5), plot.subtitle = element_text(hjust = 0.5)) + theme(text=element_text(size=25)) + theme(legend.position="none")
pKa_hill_plot <- pKa_hill_plot + geom_text_repel(aes(label = Naam), size=2.2) + guides(fill=guide_legend(title="FP class"))


pKa_hill_plot
