library(data.table)
library(tidyr)
library(dplyr)
library(gtools)
library(stringr)
library(dplyr)
library(magrittr)
library(plotrix)
library(ggplot2)
library(ggridges)
library(viridis)
library(overlapping)
titel <- "Cen.PK FBPase-GFP fusions"
ondertitel1 <- '' #subtitle1
ondertitel2 <- 'Bleedtrough and autofluorescence corrected'                   #subtitle2
TextatXaxis <- "GFP signal"   #which label should the X axis have?

#import data
wd <<- choose.dir()     #set input folder
setwd(wd)              #set input folder
filelist = list.files(pattern = "*.csv")       #make a list with all the txtfiles in a folder
combined = do.call("rbind", sapply(filelist, read.csv, simplify = FALSE))
combined$sample <- rownames(combined)
rownames(combined) <- NULL

#change column names and type of data
colnames(combined)[1] = "GFP_fluorescence"
colnames(combined)[2] = "event_number"
colnames(combined)[3] = "Sample"
combined$Sample <- gsub(".csv.*", "", combined$Sample)
combined$Sample <- gsub("ethanol2*", "ethanol", combined$Sample)
combined$log_GFP_fluorescence <- log10(combined$GFP_fluorescence)
combined <- combined[combined$GFP_fluorescence!=0, ]
combined$Sample <- as.factor(combined$Sample)
combined$log_GFP_fluorescence <- as.numeric(as.character(combined$log_GFP_fluorescence))

# determine maximal and minimal fluorescence value for axis
n <- length(combined$log_GFP_fluorescence)
max_fluorescence <- sort(combined$log_GFP_fluorescence,partial=n-(0.0001*n))[n-(0.0001*n)]
min_fluorescence <- sort(combined$log_GFP_fluorescence,partial=0.005*n)[0.005*n]

# determine amount of overlap, make list of seperate dataframes (dataframe per strain)
overlapdata <- split(combined, combined$Sample)
# list to 4 separate dataframes
list2env(overlapdata  ,.GlobalEnv)
# change name of dataframes so you dont have white spaces
FBPase_mNeongreen_ethanol<- `FBPase-ymNeongreen in ethanol`
FBPase_yoeGFP_ethanol <- `FBPase-yoeGFP in ethanol`
FBPase_yosfGFP_ethanol <- `FBPase-yosfGFP in ethanol`
WT_ethanol <- `WT in ethanol`
# make list with the 2 groups you want to measure the overlap
overlapdata1 <- list(X1=FBPase_mNeongreen_ethanol$log_GFP_fluorescence, X2=WT_ethanol$log_GFP_fluorescence)
overlapdata2 <- list(X1=FBPase_yoeGFP_ethanol$log_GFP_fluorescence, X2=WT_ethanol$log_GFP_fluorescence)
overlapdata3 <- list(X1=FBPase_yosfGFP_ethanol$log_GFP_fluorescence, X2=WT_ethanol$log_GFP_fluorescence)
# measure the overlap
plot_overlapdata <- overlap(overlapdata1, plot=TRUE)
plot_overlapdata <- overlap(overlapdata2, plot=TRUE)
plot_overlapdata <- overlap(overlapdata3, plot=TRUE)


#plot data
plot <- ggplot(data=combined, aes(x=log_GFP_fluorescence, fill=Sample))   +   geom_density(aes(y=..scaled..), lwd = 1, adjust=0.3, alpha = 0.8)  + theme_bw() + labs(title = titel, subtitle = ondertitel1) + xlab(TextatXaxis) + theme(plot.title = element_text(hjust = 0.5)) + theme(plot.subtitle = element_text(hjust = 0.5)) + theme(text=element_text(size=23)) 
plot

plot2 <- ggplot(data=combined, aes(x=log_GFP_fluorescence, y=Sample)) + theme_bw() + labs(title = titel, subtitle = ondertitel1) + xlab(TextatXaxis) + theme(plot.title = element_text(hjust = 0.5)) + theme(plot.subtitle = element_text(hjust = 0.5)) + theme(text=element_text(size=23)) 
plot2 <- plot2 + geom_density_ridges(aes(fill = Sample), scale = 10, size = 1 , alpha=0.9) +  scale_fill_brewer(palette="RdBu" ) +  coord_cartesian(xlim = c(min_fluorescence, max_fluorescence)) 

plot2
